Index: trunk/ippTools/src/chiptool.c
===================================================================
--- trunk/ippTools/src/chiptool.c	(revision 11034)
+++ trunk/ippTools/src/chiptool.c	(revision 11075)
@@ -99,9 +99,9 @@
             "SELECT"
             "   p2PendingImfile.*,"
-            "   rawScienceExp.camera"
+            "   rawExp.camera"
             " FROM p2PendingImfile"
             " JOIN p2PendingExp"
             "   USING(exp_tag)"
-            " JOIN rawScienceExp"
+            " JOIN rawExp"
             "   USING(exp_tag)"
             " LEFT JOIN p2Mask"
@@ -353,7 +353,7 @@
             "SELECT"
             "   p2ProcessedImfile.*,"
-            "   rawScienceExp.camera"
+            "   rawExp.camera"
             " FROM p2ProcessedImfile"
-            " JOIN rawScienceExp"
+            " JOIN rawExp"
             "   USING(exp_tag)"
             " WHERE "
@@ -554,13 +554,13 @@
     // where exp_tag is not in p2PendingImfile
     // where the number of entries in p2ProccessedImfile matches the .imfiles
     // entry in rawScienceExp
     psString query = psStringCopy(
         "SELECT DISTINCT"
         "   p2PendingExp.*,"
-        "   rawScienceExp.imfiles,"
+        "   rawExp.imfiles,"
         "   p2ProcessedImfile.class_id"
         " FROM p2PendingExp"
-        " JOIN rawScienceExp"
-        "   ON p2PendingExp.exp_tag = rawScienceExp.exp_tag"
+        " JOIN rawExp"
+        "   ON p2PendingExp.exp_tag = rawExp.exp_tag"
         " LEFT JOIN p2ProcessedExp"
         "   ON p2PendingExp.exp_tag = p2ProcessedExp.exp_tag"
@@ -575,5 +575,5 @@
         " GROUP BY"
         "   p2PendingExp.exp_tag"
-        " HAVING rawScienceExp.imfiles = COUNT(p2ProcessedImfile.class_id)"
+        " HAVING rawExp.imfiles = COUNT(p2ProcessedImfile.class_id)"
         );
 
@@ -773,6 +773,5 @@
         pendingExp->p1_version,
         pendingExp->p2_version,
-        pendingExp->label,
-        0   // fault code
+        pendingExp->label
     );
 }
@@ -554,13 +554,13 @@
     // where exp_tag is not in p2PendingImfile
     // where the number of entries in p2ProccessedImfile matches the .imfiles
-    // entry in rawScienceExp
+    // entry in rawExp
     psString query = psStringCopy(
         "SELECT DISTINCT"
